@@ -1,13 +1,11 @@
 package Games::Solitaire::Verify;
-
+$Games::Solitaire::Verify::VERSION = '0.1800';
 use warnings;
 use strict;
 
 use 5.008;
 
 
-our $VERSION = '0.1701';
-
 
 1; # End of Games::Solitaire::Verify
 
@@ -23,7 +21,7 @@ Games::Solitaire::Verify - verify solutions for solitaire games.
 
 =head1 VERSION
 
-version 0.1701
+version 0.1800
 
 =head1 SYNOPSIS
 
@@ -53,6 +51,10 @@ and makes sure they are correct.
 
 See L<http://pysolfc.sourceforge.net/> for more about card solitaire.
 
+=head1 VERSION
+
+version 0.1800
+
 =head1 SEE ALSO
 
 L<Games::Solitaire::Verify::Solution> , L<Games::Solitaire::Verify::State>
@@ -76,8 +78,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify or by email
-to bug-games-solitaire-verify@rt.cpan.org.
+L<https://github.com/shlomif/fc-solve/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -106,7 +107,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Games-Solitaire-Verify>
+L<https://metacpan.org/release/Games-Solitaire-Verify>
 
 =item *
 
@@ -142,14 +143,6 @@ L<http://cpanratings.perl.org/d/Games-Solitaire-Verify>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Games-Solitaire-Verify>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -160,7 +153,7 @@ L<http://cpants.cpanauthors.org/dist/Games-Solitaire-Verify>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/G/Games-Solitaire-Verify>
 
@@ -194,8 +187,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/fc-solve>
+L<https://github.com/shlomif/fc-solve>
 
-  git clone http://bitbucket.org/shlomif/fc-solve
+  git clone git://github.com/shlomif/fc-solve.git
 
 =cut
