@@ -1,11 +1,9 @@
 package Games::Solitaire::Verify::Column;
-
+$Games::Solitaire::Verify::Column::VERSION = '0.1800';
 use warnings;
 use strict;
 
 
-our $VERSION = '0.1701';
-
 use parent 'Games::Solitaire::Verify::Base';
 
 use Games::Solitaire::Verify::Exception;
@@ -201,7 +199,7 @@ columns that are composed of a sequence of cards.
 
 =head1 VERSION
 
-version 0.1701
+version 0.1800
 
 =head1 SYNOPSIS
 
@@ -219,6 +217,10 @@ version 0.1701
 
     my $queen_card = $column->pos(1);
 
+=head1 VERSION
+
+version 0.1800
+
 =head1 METHODS
 
 =head2 $column->len()
@@ -283,8 +285,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify or by email
-to bug-games-solitaire-verify@rt.cpan.org.
+L<https://github.com/shlomif/fc-solve/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -298,7 +299,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc Games::Solitaire::Verify
+  perldoc Games::Solitaire::Verify::Column
 
 =head2 Websites
 
@@ -313,7 +314,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Games-Solitaire-Verify>
+L<https://metacpan.org/release/Games-Solitaire-Verify>
 
 =item *
 
@@ -349,14 +350,6 @@ L<http://cpanratings.perl.org/d/Games-Solitaire-Verify>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Games-Solitaire-Verify>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -367,7 +360,7 @@ L<http://cpants.cpanauthors.org/dist/Games-Solitaire-Verify>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/G/Games-Solitaire-Verify>
 
@@ -401,8 +394,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/fc-solve>
+L<https://github.com/shlomif/fc-solve>
 
-  git clone http://bitbucket.org/shlomif/fc-solve
+  git clone git://github.com/shlomif/fc-solve.git
 
 =cut
