@@ -1,13 +1,11 @@
 package Games::Solitaire::Verify::Solution;
-
+$Games::Solitaire::Verify::Solution::VERSION = '0.1800';
 use warnings;
 use strict;
 
 use 5.008;
 
 
-our $VERSION = '0.1701';
-
 use parent 'Games::Solitaire::Verify::Solution::Base';
 
 use Games::Solitaire::Verify::Exception;
@@ -185,7 +183,7 @@ of Freecell Solver (or a similar solve)
 
 =head1 VERSION
 
-version 0.1701
+version 0.1800
 
 =head1 SYNOPSIS
 
@@ -217,6 +215,10 @@ version 0.1701
         print "Solution is OK";
     }
 
+=head1 VERSION
+
+version 0.1800
+
 =head1 METHODS
 
 =head2 Games::Solitaire::Verify::Solution->new({variant => $variant, input_fh => $input_fh})
@@ -248,8 +250,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify or by email
-to bug-games-solitaire-verify@rt.cpan.org.
+L<https://github.com/shlomif/fc-solve/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -263,7 +264,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc Games::Solitaire::Verify
+  perldoc Games::Solitaire::Verify::Solution
 
 =head2 Websites
 
@@ -278,7 +279,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Games-Solitaire-Verify>
+L<https://metacpan.org/release/Games-Solitaire-Verify>
 
 =item *
 
@@ -314,14 +315,6 @@ L<http://cpanratings.perl.org/d/Games-Solitaire-Verify>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Games-Solitaire-Verify>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -332,7 +325,7 @@ L<http://cpants.cpanauthors.org/dist/Games-Solitaire-Verify>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/G/Games-Solitaire-Verify>
 
@@ -366,8 +359,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/fc-solve>
+L<https://github.com/shlomif/fc-solve>
 
-  git clone http://bitbucket.org/shlomif/fc-solve
+  git clone git://github.com/shlomif/fc-solve.git
 
 =cut
