@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::VariantsMap;
-
+$Games::Solitaire::Verify::VariantsMap::VERSION = '0.1800';
 use strict;
 use warnings;
 
@@ -8,8 +8,6 @@ use Games::Solitaire::Verify::VariantParams;
 use parent 'Games::Solitaire::Verify::Base';
 
 
-our $VERSION = '0.1701';
-
 sub _init
 {
     return 0;
@@ -238,7 +236,11 @@ their parameters.
 
 =head1 VERSION
 
-version 0.1701
+version 0.1800
+
+=head1 VERSION
+
+version 0.1800
 
 =head1 FUNCTIONS
 
@@ -341,7 +343,7 @@ L<http://search.cpan.org/dist/Games-Solitaire-Verify>
 
 Copyright 2008 Shlomi Fish.
 
-This program is released under the following license: MIT/X11
+This program is released under the following license: MIT/Expat
 ( L<http://www.opensource.org/licenses/mit-license.php> ).
 
 =head1 AUTHOR
@@ -359,8 +361,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify or by email
-to bug-games-solitaire-verify@rt.cpan.org.
+L<https://github.com/shlomif/fc-solve/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -374,7 +375,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc Games::Solitaire::Verify
+  perldoc Games::Solitaire::Verify::VariantsMap
 
 =head2 Websites
 
@@ -389,7 +390,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Games-Solitaire-Verify>
+L<https://metacpan.org/release/Games-Solitaire-Verify>
 
 =item *
 
@@ -425,14 +426,6 @@ L<http://cpanratings.perl.org/d/Games-Solitaire-Verify>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Games-Solitaire-Verify>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -443,7 +436,7 @@ L<http://cpants.cpanauthors.org/dist/Games-Solitaire-Verify>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/G/Games-Solitaire-Verify>
 
@@ -477,8 +470,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/fc-solve>
+L<https://github.com/shlomif/fc-solve>
 
-  git clone http://bitbucket.org/shlomif/fc-solve
+  git clone git://github.com/shlomif/fc-solve.git
 
 =cut
